#define BREAKPOINT_VALUE { 0x4e, 0x4f }
#define BREAKPOINT_LENGTH 2
#define DECR_PC_AFTER_BREAK 2

#define LT_ELFCLASS	ELFCLASS32
#define LT_ELF_MACHINE	EM_68K
